#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-
"""
Dieses Programm implementiert ein kleines Spiel als Illustration
fr das Gesetz der groen Zahlen.  Es nimmt Erwartungswert
und Varianz einer Gauverteilung sowie die Zahl der Experimente,
die durchgefhrt werden sollen und gibt die Zahl der Experimente
aus, fr die |H_n-E|>m war.

Vgl. Skript: "Das schwache Gesetz der groen Zahlen"
"""

import sys, random

def runExperiment(mean, variance, numExper):
	resSum = 0
	for i in range(numExper):
		resSum += random.gauss(mean, variance)
	return resSum/numExper

def runChebGame(mean, variance, numExper, numRuns=200):
	devFreqs = {}
	for i in range(numRuns):
		curRes = runExperiment(mean, variance, numExper)
		sys.stdout.write("\rRun %d: %f"%(i, curRes))
		sys.stdout.flush()
		devThresh = int(abs(curRes-mean))
		devFreqs[devThresh] = devFreqs.get(devThresh, 0)+1
	sys.stdout.write("\r"+" "*70+"\n")
	return devFreqs

def outputResult(devFreqs):
	devSizes = devFreqs.keys()
	devSizes.sort()
	devSizes.reverse()
	totalRuns = float(sum(devFreqs.values()))
	totalSoFar = 0
	for devSize in devSizes:
		totalSoFar += devFreqs[devSize]/totalRuns
		print "Relative Hufigkeit |H_n-E(X)|>=%d: %f"%(
			devSize, totalSoFar)

if __name__=="__main__":
	try:
		mean, variance, numExper = (float(sys.argv[1]), 
			float(sys.argv[2]), int(sys.argv[3]))
	except (ValueError, IndexError):
		sys.stderr.write("Usage: %s <mean> <variance> <numExper>\n"%(
			sys.argv[0]))
		sys.exit(1)
	outputResult(
		runChebGame(mean, variance, numExper))
